@@ -48,6 +48,7 @@ class GitRssPlugin(BasePlugin):
         ("categories", config_options.Type(list, default=None)),
         ("comments_path", config_options.Type(str, default=None)),
         ("date_from_meta", config_options.Type(dict, default=None)),
+        ("enabled", config_options.Type(bool, default=True)),
         ("feed_ttl", config_options.Type(int, default=1440)),
         ("image", config_options.Type(str, default=None)),
         ("length", config_options.Type(int, default=20)),
@@ -83,6 +84,11 @@ class GitRssPlugin(BasePlugin):
         :return: plugin configuration object
         :rtype: dict
         """
+
+        # Skip if disabled
+        if not self.config.get("enabled"):
+            return config
+
         # check template dirs
         if not Path(DEFAULT_TEMPLATE_FILENAME).is_file():
             raise FileExistsError(DEFAULT_TEMPLATE_FILENAME)
@@ -175,6 +181,11 @@ class GitRssPlugin(BasePlugin):
         :return: HTML rendered from Markdown source as string
         :rtype: str
         """
+
+        # Skip if disabled
+        if not self.config.get("enabled"):
+            return
+
         # skip pages that don't match the config var match_path
         if not self.match_path_pattern.match(page.file.src_path):
             return
@@ -239,6 +250,11 @@ class GitRssPlugin(BasePlugin):
         :return: global configuration object
         :rtype: dict
         """
+
+        # Skip if disabled
+        if not self.config.get("enabled"):
+            return
+
         # pretty print or not
         pretty_print = self.config.get("pretty_print", False)
 
